<?php
/*
   BloxPress2
   ----------------------
   Copyright (C) 2006, Kjell Bublitz
   www.bloxpress.org / kb@bloxpress.org

   Bloxpress Template Functions

*/

// Current Version
// =========================================================================
define( 'BP_VERSION', '1.5.7' );

// Setup Path Constants
// =========================================================================
define( 'BP_DEBUG', false );
define( 'BP_BASEDIR', TEMPLATEPATH );
define( 'BP_BASEURL', get_bloginfo( 'template_directory' ) );
define( 'BP_TEMPLATE', get_option( 'bp_template' ) );
define( 'BP_BLOCKDIR', BP_BASEDIR . '/blocks' );
define( 'BP_LAYOUTDIR', BP_BASEDIR . '/layouts' );
define( 'BP_SYSTEMDIR', BP_BASEDIR . '/system' );
define( 'BP_CACHEDIR', BP_SYSTEMDIR . '/cache' );
define( 'BP_WORKDIR', BP_SYSTEMDIR . '/workdir' );
define( 'BP_PHPLIBS', BP_SYSTEMDIR . '/phplibs' );
define( 'BP_TEMPLATEDIR', BP_BASEDIR . '/templates' );
define( 'BP_TEMPLATEURL', BP_BASEURL . '/templates' );
define( 'BP_CURRENTDIR', BP_TEMPLATEDIR . '/' . BP_TEMPLATE );
define( 'BP_CURRENTURL', BP_TEMPLATEURL . '/' . BP_TEMPLATE );

// Register Tempvar for Admin
session_register('bp2fileblocks');

// Query Admin Options
// =========================================================================
$bpOptions = get_option( 'bp_options' );

// Read ThemeInfo
// =========================================================================
if ( file_exists( BP_CURRENTDIR . '/style.css' ) ) {
    $themeData = bp_get_theme_data( BP_CURRENTDIR . '/style.css' );
    $bloxpressColumns = $themeData['columns'];
} else {
    // buggy..
    //bp_error( 'The selected template has no style.css in its directory' );
}


// Hookup wordpress
// =========================================================================
add_action( 'wp_head', 'bp_draw_header' );

add_filter( '404_template', 'bp_get_404_template', 1 );
add_filter( 'archive_template', 'bp_get_archive_template', 1 );
add_filter( 'author_template', 'bp_get_author_template', 1 );
add_filter( 'category_template', 'bp_get_category_template', 1 );
add_filter( 'date_template', 'bp_get_date_template', 1 );
add_filter( 'home_template', 'bp_get_home_template', 1 );
add_filter( 'page_template', 'bp_get_page_template', 1 );
add_filter( 'paged_template', 'bp_get_paged_template', 1 );
add_filter( 'search_template', 'bp_get_search_template', 1 );
add_filter( 'single_template', 'bp_get_single_template', 1 );
add_filter( 'comments_popup_template', 'bp_get_comments_popup_template', 1 );
add_filter( 'comments_template', 'bp_get_comments_template', 1 );

do_action( 'template_redirect' );

// Layoutgenerator
// =========================================================================
require_once( BP_BASEDIR . '/system/bloxpress.php' );


// Replacement for bloginfo('template_directory')
// =========================================================================
function bp_template_url()
{
    echo BP_CURRENTURL; // complete url to the template dir
}
function bp_template_dir()
{
    echo BP_CURRENTDIR; // full path to the template dir
}

// Optional Tag for the commentform. Contains necessary classes. (beta)
// =========================================================================
function bp_form_tag()
{
    echo '<form action="' . get_option( 'siteurl' ) . '/wp-comments-post.php" method="post" class="commentform" id="commentform">';
}

// Grabs the important Header from a templates style.css
// =========================================================================
function bp_get_theme_data( $theme_file )
{
    $theme_data = implode( '', file( $theme_file ) );
    preg_match( "|Theme Name:(.*)|i", $theme_data, $theme_name );
    preg_match( "|Theme URI:(.*)|i", $theme_data, $theme_uri );
    preg_match( "|Description:(.*)|i", $theme_data, $theme_desc );
    preg_match( "|Version:(.*)|i", $theme_data, $theme_ver );
    preg_match( "|Author:(.*)|i", $theme_data, $theme_author );

    // bp-only
    preg_match( "|ImageFolder:(.*)|i", $theme_data, $theme_img );
    preg_match( "|Columns:(.*)|i", $theme_data, $theme_cols );
    preg_match( "|MenuTarget:(.*)|i", $theme_data, $theme_menu );

    $columns = explode( ',', $theme_cols[1] );
    $this_cols = array();
    for( $i = 0;$i < count( $columns );$i++ ) {
        $this_cols[] = trim( $columns[$i] );
    }
    $theme_cols[1] = $this_cols;

    $themeInfo['name'] = trim($theme_name[1]);
    $themeInfo['url'] = trim($theme_uri[1]);
    $themeInfo['desc'] = trim($theme_desc[1]);
    $themeInfo['version'] = trim($theme_ver[1]);
    $themeInfo['author'] = trim($theme_author[1]);
    $themeInfo['imgdir'] = trim($theme_img[1]);
    $themeInfo['columns'] = $theme_cols[1];
    $themeInfo['blockMenu'] = trim($theme_menu[1]);

    return $themeInfo;
}

// Grabs the Header from a blockfile
// =========================================================================
function bp_get_block_data( $block_file )
{
    $block_data = implode( '', file( $block_file ) );
    preg_match( "|Caption:(.*)|i", $block_data, $block_caption );
    preg_match( "|Messsage:(.*)|i", $block_data, $block_msg );
    preg_match( "|Description:(.*)|i", $block_data, $block_desc );
    preg_match( "|Author:(.*)|i", $block_data, $block_autor );
    preg_match( "|Homepage:(.*)|i", $block_data, $block_homepage );

    $blockInfo = array();
    $blockInfo['caption'] = trim($block_caption[1]);
    $blockInfo['message'] = trim($block_msg[1]);
    $blockInfo['description'] = trim($block_desc[1]);
    $blockInfo['author'] = trim($block_autor[1]);
    $blockInfo['homepage'] = trim($block_homepage[1]);

    return $blockInfo;
}

// System functions
// =========================================================================
function bp_error( $msg )
{
    echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">';
    echo "<html><head><title>" . get_bloginfo( 'name' ) . " &raquo; Bloxpress Error</title></head><body>";
    echo "<center><h2 style='margin:0;color:#aa0000;font-family:sans-serif'>Bloxpress Error</h2>";
    echo "<p style='margin:0;padding:0;color:#555;font-family:sans-serif'>" . $msg . "</p>";
    echo "</center></body></html>";
    exit;
}

function bp_js_columns()
{
    global $bloxpressColumns;
    for( $i = 0;$i < count( $bloxpressColumns );$i++ ) {
        $jsArray .= "'" . $bloxpressColumns[$i] . "'";
        if ( $i != ( count( $bloxpressColumns )-1 ) ) {
            $jsArray .= ",";
        }
    }
    $jsString = "var Columns = new Array(" . $jsArray . ");";
    return $jsString;
}

function bp_check_online() {
    return file_get_contents('http://bloxpress.org/update/version.txt');
}

// Alternate Template Tags for Conversion
// =========================================================================
function bp_get_header()
{
    if ( file_exists( BP_CURRENTDIR . '/header.php' ) ) {
        load_template( BP_CURRENTDIR . '/header.php' );
    } else {
        load_template( ABSPATH . 'wp-content/themes/default/header.php' );
    }
}

function bp_get_footer()
{
    if ( file_exists( BP_CURRENTDIR . '/footer.php' ) ) {
        load_template( BP_CURRENTDIR . '/footer.php' );
    } else {
        load_template( ABSPATH . 'wp-content/themes/default/footer.php' );
    }
}

function bp_get_sidebar()
{
    if ( file_exists( BP_CURRENTDIR . '/sidebar.php' ) ) {
        load_template( BP_CURRENTDIR . '/sidebar.php' );
    } else {
        load_template( ABSPATH . 'wp-content/themes/default/sidebar.php' );
    }
}
// Query Templates for Wordpress Hooks
// =========================================================================
function bp_query_tpl( $type )
{
    $template = '';
    if ( file_exists( BP_CURRENTDIR . "/{$type}.php" ) )
        $template = BP_CURRENTDIR . "/{$type}.php";
    return $template;
}

function bp_get_404_template()
{
    return bp_query_tpl( '404' );
}

function bp_get_archive_template()
{
    return bp_query_tpl( 'archive' );
}

function bp_get_author_template()
{
    return bp_query_tpl( 'author' );
}

function bp_get_date_template()
{
    return bp_query_tpl( 'date' );
}

function bp_get_paged_template()
{
    return bp_query_tpl( 'paged' );
}

function bp_get_search_template()
{
    return bp_query_tpl( 'search' );
}

function bp_get_single_template()
{
    return bp_query_tpl( 'single' );
}

function bp_get_comments_template()
{
    return bp_query_tpl( 'comments' );
}
// Worpdress replacements
// =========================================================================
function bp_get_home_template()
{
    $template = '';

    if ( file_exists( BP_CURRENTDIR . "/home.php" ) ) {
        $template = BP_CURRENTDIR . "/home.php";
    } else if ( file_exists( BP_CURRENTDIR . "/index.php" ) ) {
        $template = BP_CURRENTDIR . "/index.php";
    }
    return $template;
}

function bp_get_category_template()
{
    $template = '';
    if ( file_exists( BP_CURRENTDIR . "/category-" . get_query_var( 'cat' ) . '.php' ) ) {
        $template = BP_CURRENTDIR . "/category-" . get_query_var( 'cat' ) . '.php';
    } else if ( file_exists( BP_CURRENTDIR . "/category.php" ) ) {
        $template = BP_CURRENTDIR . "/category.php";
    }
    return $template;
}

function bp_get_attachment_template()
{
    global $posts;
    $type = explode( '/', $posts[0]->post_mime_type );
    if ( $template = bp_query_tpl( $type[0] ) ) {
        return $template;
    } elseif ( $template = bp_query_tpl( $type[1] ) ) {
        return $template;
    } elseif ( $template = bp_query_tpl( "$type[0]_$type[1]" ) ) {
        return $template;
    } else {
        return bp_query_tpl( 'attachment' );
    }
}

function bp_get_comments_popup_template()
{
    if ( file_exists( BP_CURRENTDIR . '/comments-popup.php' ) ) {
        $template = BP_CURRENTDIR . '/comments-popup.php';
    } else {
        $template = get_theme_root() . '/default/comments-popup.php';
    }
    return $template;
}

function bp_get_page_template()
{
    global $wp_query;

    $id = $wp_query->post->ID;
    $template = get_post_meta( $id, '_wp_page_template', true );

    if ( 'default' == $template ) {
        $template = '';
    }

    if ( ! empty( $template ) && file_exists( BP_CURRENTDIR . "/$template" ) ) {
        $template = BP_CURRENTDIR . "/$template";
    } else if ( file_exists( BP_CURRENTDIR . "/page.php" ) ) {
        $template = BP_CURRENTDIR . "/page.php";
    } else {
        $template = '';
    }
    return $template;
}
// Template Chooser
// =========================================================================
function bp_get_templates()
{
    $templates = array();
    if ( is_dir( BP_TEMPLATEDIR ) ) {
        $BP_BASEDIR = opendir( BP_TEMPLATEDIR );
        while ( ( $tplsubdir = readdir( $BP_BASEDIR ) ) !== false ) {
            if ( $tplsubdir != '.' && $tplsubdir != '..' && $tplsubdir != 'CVS' ) {
                if ( is_dir( BP_TEMPLATEDIR . '/' . $tplsubdir ) ) {
                    $templates[] = $tplsubdir;
                }
            }
        }
    }
    return $templates;
}

function bp_template_select()
{
    $templates = bp_get_templates();
    $currentTpl = get_option( 'bp_template' );
    $tplOptions = "";

    foreach( $templates as $template ) {
        if ( $template == $currentTpl ) {
            $sel = ' selected';
        } else {
            $sel = '';
        }
        $tplOptions .= '<option value="' . $template . '"' . $sel . '>' . $template . '</option>';
    }

    $select = '<select id="opt0" name="bp_template">' . $tplOptions . '</select>';
    echo $select . "\n";
}

// Header
// =========================================================================
function bp_draw_header()
{
    echo '
    <!-- bloxpress -->
    <style type="text/css" media="screen">
        @import url(' . BP_CURRENTURL . '/style.css);
        @import url(' . BP_BASEURL . '/system/styles/blocks.css);

        /* hide script only elements */
        .noscript {visibility:hidden;}
        form.noscript{display:none;}
    </style>
    <script type="text/javascript">
    <!--
        ' . bp_js_columns() . '
    //-->
    </script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/workdir/bloxpressConfig.js"></script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/javascript/libraries/prototype.js"></script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/javascript/libraries/fastinit.js"></script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/javascript/libraries/behaviour.js"></script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/javascript/scriptaculous/scriptaculous.js"></script>
    <script type="text/javascript" src="' . BP_BASEURL . '/system/javascript/bloxpress/bloxpress.js"></script>
    <!-- /bloxpress -->
    ';
}

// Config Javascript
// =========================================================================
function bp_write_js_config()
{
    $filename = BP_WORKDIR . '/bloxpressConfig.js';
    if ( !$handle = fopen( $filename, "w+" ) ) {
        return 2;
    }
    if ( !fwrite( $handle, bp_get_js_config() ) ) {
        return 3;
    } else {
        fclose( $handle );
        return 1;
    }
}

function bp_get_js_config()
{
    global $themeData;

    $bpOptions = get_option('bp_options');

    $jsconfig = "var jsiFolder = '" . $themeData['imgdir'] . "';\n";
    $jsconfig .= "var tplpath = '" . BP_BASEURL . "/';\n";
    $jsconfig .= "var themepath = '" . BP_BASEURL . "/templates/" . get_option( 'bp_template' ) . "/';\n";
    $jsconfig .= "var keepCookieDays = " . $bpOptions['cookieDays'] . ";\n";
    $jsconfig .= "var noURLMessage = '" . $bpOptions['noURLMessage'] . "';\n";
    $jsconfig .= "var noTextMessage = '" . $bpOptions['noTextMessage'] . "';\n";
    $jsconfig .= "var commentMessage = '" . $bpOptions['commentMessage'] . "';\n";
    $jsconfig .= "var updateMessage = '" . $bpOptions['updateMessage'] . "';\n";
    $jsconfig .= "var addblockHelp = '" . $bpOptions['addblockHelp'] . "';\n";
    $jsconfig .= "var loadIconImage ='" . $bpOptions['loadIconImage'] . "';\n";
    $jsconfig .= "var searchIconImage = '" . $bpOptions['searchIconImage'] . "';\n";
    $jsconfig .= "var errorIconImage = '" . $bpOptions['errorIconImage'] . "';\n";
    $jsconfig .= "var closeIconImage = '" . $bpOptions['closeIconImage'] . "';\n";
    $jsconfig .= "var minIconImage = '" . $bpOptions['minIconImage'] . "';\n";
    $jsconfig .= "var maxIconImage = '" . $bpOptions['maxIconImage'] . "';\n";
    $jsconfig .= "var ghostEffect = " . $bpOptions['ghostEffect'] . ";\n";
    $jsconfig .= "var minOnMove = " . $bpOptions['minOnMove'] . ";\n";
    $jsconfig .= "var statefulLinks = " . $bpOptions['statefulLinks'] . ";\n";
    $jsconfig .= "var draggableClass = '" . $bpOptions['draggableClass'] . "';\n";
    $jsconfig .= "var postContentClass = '" . $bpOptions['postContentClass'] . "';\n";
    $jsconfig .= "var blockMenuTarget = '" . $bpOptions['blockMenuTarget'] . "';\n";
    $jsconfig .= "var sortableTag = '" . $bpOptions['sortableTag'] . "';\n";
    $jsconfig .= "var sortableRoot = '" . $bpOptions['sortableRoot'] . "';\n";
    $jsconfig .= "var updateMessageTop = '" . $bpOptions['updateMessageTop'] . "';\n";
    $jsconfig .= "var updateMessageLeft = '" . $bpOptions['updateMessageLeft'] . "';\n";

    if ( $bpOptions['enableHover'] == 'false' ) {
        $hoverClassName = 'var hoverClassName = null;';
    } else {
        $hoverClassName = "var hoverClassName = '" . $bpOptions['hoverClassName'] . "';";
    }

    $jsconfig .= $hoverClassName . "\n";
    $jsconfig .= "if(statefulLinks){\n";
    $jsconfig .= "var resetSuccess = '" . $bpOptions['resetSuccess'] . "';\n";
    $jsconfig .= "var resetRevert = '" . $bpOptions['resetRevert'] . "';\n";
    $jsconfig .= "var expandAll = '" . $bpOptions['expandAll'] . "';\n";
    $jsconfig .= "var collapseAll = '" . $bpOptions['collapseAll'] . "';\n";
    $jsconfig .= "}\n";

    return $jsconfig;
}

// Auto Install / Update
// =========================================================================
if ( !get_option( 'bp_version' ) || get_option( 'bp_version' ) < BP_VERSION )
{
    $bpOptions = array(); // Default Options
    $bpOptions['noURLMessage'] = "Doh! That is not a URL dude!";
    $bpOptions['noTextMessage'] = "How about some text first?";
    $bpOptions['commentMessage'] = "Posting comment, please wait";
    $bpOptions['updateMessage'] = "Settings saved!";
    $bpOptions['addblockHelp'] = 'This is the blockmenu. Select an item from the list and drag and drop it on the right or left column to make it appear.';
    $bpOptions['loadIconImage'] = "loading.gif";
    $bpOptions['searchIconImage'] = "searching.gif";
    $bpOptions['errorIconImage'] = "error.gif";
    $bpOptions['closeIconImage'] = "icon_remove.gif";
    $bpOptions['minIconImage'] = "icon_minimize.gif";
    $bpOptions['maxIconImage'] = "icon_maximize.gif";
    $bpOptions['statefulLinks'] = 'true';
    $bpOptions['minOnMove'] = 'true';
    $bpOptions['resetSuccess'] = 'layout dumped! reload the page';
    $bpOptions['resetRevert'] = 'reset layout';
    $bpOptions['expandAll'] = 'expand all';
    $bpOptions['collapseAll'] = 'collapse all';
    $bpOptions['draggableClass'] = 'captionTitle';
    $bpOptions['postContentClass'] = 'postcontent';
    $bpOptions['hoverClassName'] = 'colhover';
    $bpOptions['blockMenuTarget'] = 'blockmenu';
    $bpOptions['sortableTag'] = 'li';
    $bpOptions['sortableRoot'] = 'ul';
    $bpOptions['ghostEffect'] = 'false';
    $bpOptions['enableHover'] = 'true';
    $bpOptions['updateMessageTop'] = '0px';
    $bpOptions['updateMessageLeft'] = '0px';
    $bpOptions['cookieDays'] = '30';
    $bpTemplate = 'default';

    if ( !get_option( 'bp_version' ) ) {
        add_option( 'bp_version', BP_VERSION, 'Bloxpress Version' );
    } else {
        update_option( 'bp_version', BP_VERSION );
    }

    if ( !get_option( 'bp_options' ) ) {
        add_option( 'bp_options', $bpOptions, 'Bloxpress Options' );
    }

    $presets = array();

    $presets['default']['default']['bloxpress']['column'][0]['block'][0]['caption'] = 'Search Blog';
    $presets['default']['default']['bloxpress']['column'][0]['block'][0]['file'] = 'search.php';
    $presets['default']['default']['bloxpress']['column'][0]['block'][0]['message'] = 'Live Search';

    $presets['default']['default']['bloxpress']['column'][0]['block'][1]['caption'] = 'Categories';
    $presets['default']['default']['bloxpress']['column'][0]['block'][1]['file'] = 'categories.php';
    $presets['default']['default']['bloxpress']['column'][0]['block'][1]['message'] = 'Post Categories';

    $presets['default']['default']['bloxpress']['column'][0]['block'][2]['caption'] = 'Pages';
    $presets['default']['default']['bloxpress']['column'][0]['block'][2]['file'] = 'pages.php';
    $presets['default']['default']['bloxpress']['column'][0]['block'][2]['message'] = 'Page List';

    $presets['default']['default']['bloxpress']['column'][0]['block'][3]['caption'] = 'Calendar';
    $presets['default']['default']['bloxpress']['column'][0]['block'][3]['file'] = 'calendar.php';
    $presets['default']['default']['bloxpress']['column'][0]['block'][3]['message'] = 'Post Calendar';

    $presets['default']['default']['bloxpress']['column'][1]['block'][0]['caption'] = 'Archive';
    $presets['default']['default']['bloxpress']['column'][1]['block'][0]['file'] = 'archive.php';
    $presets['default']['default']['bloxpress']['column'][1]['block'][0]['message'] = 'Archives';

    $presets['default']['default']['bloxpress']['column'][1]['block'][1]['caption'] = 'Blogroll';
    $presets['default']['default']['bloxpress']['column'][1]['block'][1]['file'] = 'links.php';
    $presets['default']['default']['bloxpress']['column'][1]['block'][1]['message'] = 'Linklist';

    $presets['default']['default']['bloxpress']['column'][1]['block'][2]['caption'] = 'Layouts';
    $presets['default']['default']['bloxpress']['column'][1]['block'][2]['file'] = 'layouts.php';
    $presets['default']['default']['bloxpress']['column'][1]['block'][2]['message'] = 'Layout List';


    if ( !get_option( 'bp_presets' ) ) {
        add_option( 'bp_presets', $presets, 'Bloxpress XML Presets' );
    }

    if ( !get_option( 'bp_template' ) ) {
        add_option( 'bp_template', $bpTemplate, 'Selected Bloxpress Template' );
    }

    $themeData = bp_get_theme_data( BP_TEMPLATEDIR . '/' . $bpTemplate . '/style.css' );

    bp_write_js_config();
    wp_cache_flush();
}

// enable template php code for designers
// =========================================================================
if(file_exists(BP_CURRENTDIR . '/functions.php')) {
    include_once( BP_CURRENTDIR . '/functions.php' );
}

// admin pages
// =========================================================================
include_once( BP_BASEDIR . '/system/admin_options.php' );
include_once( BP_BASEDIR . '/system/admin_blocks.php' );
include_once( BP_BASEDIR . '/system/admin_layouts.php' );
include_once( BP_BASEDIR . '/system/admin_system.php' );

?>