/**
 * BloxPress2
 * ----------------------
 * Copyright (C) 2006, Kjell Bublitz
 * www.bloxpress.org
 *
 * @type: Class
 * @fileoverview Bloxpress Behaviour Rules
 * @author Kjell Bublitz kb@bloxpress.org
 * @version 1.6
 */
BloxpressBehaviour = {
    '.caption h3' : function(element){
        element.onmousedown = function() {
           element.style.cursor = Bloxpress.grabbingCursor;
        },
        element.onmouseup = function() {
           element.style.cursor = Bloxpress.grabCursor;
        }
    },
    'a.remove' : function(element) {
        element.onclick = function() {
            Bloxpress.builderRemove(element.parentNode.parentNode);
        }
    },
    'a.minmax' : function(element) {
        element.onclick = function() {
            Element.cleanWhitespace(element.parentNode.parentNode);
            if (!Element.visible(element.parentNode.nextSibling)) {
                element.title = 'Minimize this Block';
                element.firstChild.src = minImagePath;
                Element.show(element.parentNode.nextSibling);
                Bloxpress.blockManager(element.parentNode.parentNode.id, 'remove');
            } else {
                element.title = 'Maximize this Block';
                element.firstChild.src = maxImagePath;
                Element.hide(element.parentNode.nextSibling);
                Bloxpress.blockManager(element.parentNode.parentNode.id, 'add');
            }
        }
    },
    'a.maximize' : function(element) {
        element.onclick = function() {
            Bloxpress.blockToggle(element.parentNode.parentNode, 'show')
        }
    },
    'a.addblocks' : function(element) {
        element.onclick = function() {
            Bloxpress.blocksMenuToggle();
        }
    },
    'a.clearlayout' : function(element) {
        element.onclick = function() {
            Bloxpress.cookie.remove();

            if (statefulLinks) {
                fx = new Effect.Highlight(element);
                element.id = 'reset';
                Element.update('reset', resetSuccess);
                setTimeout("Element.update('reset', resetRevert)", 2000);
            }
        }
    },
    'a.scrolljump' : function(element) {
        element.onclick = function() {
            var href = element.getAttribute('href');
            fx= new Effect.ScrollTo(href.substr(1));
            return false;
        }
    },
    'a.gotocomments' : function(element) {
        element.onclick = function() {
            fx= new Effect.ScrollTo('comments');
            return false;
        }
    },
    'a.contentnext' : function(element) {
        element.onclick = function() {
            lastDiv = Bloxpress.domLast($('posts'));
            postDiv = $(element.parentNode.parentNode.parentNode);
            if (postDiv != lastDiv) {
                fx = new Effect.ScrollTo(Bloxpress.domAfter(postDiv));
            } else {
                fx = new Effect.ScrollTo('footer');
            }
        }
    },
    'a.contentprev' : function(element) {
        element.onclick = function() {
            firstDiv = Bloxpress.domFirst($('posts'));
            postDiv = $(element.parentNode.parentNode.parentNode);
            if (postDiv != firstDiv) {
                fx = new Effect.ScrollTo(Bloxpress.domBefore(postDiv));
            } else {
                fx = new Effect.ScrollTo('header');
            }
        }
    },
    'a.contentswitch' : function(element) {
        element.onclick = function() {
            var postDiv = element.parentNode.parentNode.parentNode;
            var postContent = document.getElementsByClassName(postContentClass, postDiv);
            postContent.each(function(post) {
               fx = new Effect.toggle(post, 'blind', {duration:0.5})
            });
        }
    },
    'a.switchallposts' : function(element) {
        element.onclick = function()
        {
            document.getElementsByClassName(postContentClass).each(
                function(element) {
                    Element.toggle(element);
                }
            );
            if (statefulLinks) {
                if (element.innerHTML == collapseAll) {
                    Element.update(element, expandAll);
                } else {
                    Element.update(element, collapseAll);
                }
            }
        }
    },
    'a.readrss' : function(element) {
        element.onclick = function()
        {
            console.log(element.parentNode.id);

        }
    },
    'form.search' : function(element) {
        indicatorId = Bloxpress.getRandom('processing');
        indicatorEl = Builder.node('div',{id:indicatorId,style:'display:none;padding:0.3em'}, [
                Builder.node('img',{src:spinnerImagePath}), ' searching...' ]);
        element.appendChild(indicatorEl);

        inputfield = element.getElementsByTagName('input');
        inputfield[0].setAttribute('autocomplete', 'off');
        inputfield = inputfield[0].id;

        resultfield = element.getElementsByTagName('div');
        resultfield = resultfield[0].id;

        new Ajax.Autocompleter(inputfield, resultfield, tplpath+'templates/search_ajax.php', {
           method:'get', frequency:0, param: 's', minChars: 3, indicator:indicatorId, updateElement: function(resultItem) {
                window.location = resultItem.getElementsByTagName('span')[0].innerHTML;
           }
        });
    },
    'form.rssfeed' : function(element) {
        element.onsubmit = function()
        {
            var formdata = Form.serialize(element).split('&');
            var randomID = formdata[0].split('=')[1];
            var feedURL = unescape(formdata[1].split('=')[1]);
            if (Bloxpress.isUrl(feedURL)) {
                new BloxpressAjaxRequest('rssfeed', randomID);
            } else {
                Bloxpress.errorMsg(element, noURLMessage);
            }
            return false;
        }
    },
    'form.delicious' : function(element) {
        element.onsubmit = function()
        {
            var formdata = Form.serialize(element).split('&');
            var randomID = formdata[0].split('=')[1];
            new BloxpressAjaxRequest('delicious', randomID);
            return false;
        }
    },
    'form.flickr' : function(element) {
        element.onsubmit = function()
        {
            var formdata = Form.serialize(element).split('&');
            var randomID = formdata[0].split('=')[1];
            new BloxpressAjaxRequest('flickr', randomID);
            return false;
        }
    },
    'form.technorati' : function(element) {
        element.onsubmit = function()
        {
            var formdata = Form.serialize(element).split('&');
            var randomID = formdata[0].split('=')[1];
            var query = formdata[1].split('=')[1];
            if (query != "") {
                new BloxpressAjaxRequest('technorati', randomID);
            } else {
                Bloxpress.errorMsg(element, noTextMessage);
            }
            return false;
        }
    },
    'form.commentform' : function(element) {
        element.onsubmit = function() {
            var nofityElement = Builder.node('div', {id:'comindicator',className:'nofity'}, [Builder.node('img', {src:spinnerImagePath,style:'vertical-align:middle'}),' ' + commentMessage + ' ',]);
            new Ajax.Updater('commentlist', tplpath + 'templates/comments_ajax.php', {
                onLoading:function() {
                    $('commentlist').appendChild(nofityElement);
                },
                onComplete:function(request) { new Effect.Fade('comindicator', {
                    duration: 0.4, afterFinishInternal:function(){
                            Element.remove('comindicator');
                        }
                    });

                },
                parameters:Form.serialize('commentform'),
                asynchronous:true, evalScripts:true,
                insertion:Insertion.Bottom
            });
            return false;
        }
    }
};
Behaviour.register(BloxpressBehaviour);