/**
 * BloxPress2
 * ----------------------
 * Copyright (C) 2006, Kjell Bublitz
 * www.bloxpress.org
 *
 * @type: Baseclass
 * @fileoverview Bloxpress Main
 * @author Kjell Bublitz kb@bloxpress.org
 * @version 1.4.2
 */
Bloxpress = {
	bType: -1,
    columns: Columns,
    cookie: new BloxpressCookie('bp2layout'),
    managedBlocksCookie: new BloxpressCookie('bp2blocks'),
    initialize: function() {
        //this.creator = new BloxpressCreator();
        this.hideAllmanaged();
		this.getCursors();
		this.setupCursors();
        this.blockManagerSetup();
        this.blocksFetch();
        this.createSortables();
    },
    setupColumn: function(columnId) {
        Sortable.create(columnId, {
            tag: sortableTag, zindex: 100, containment: this.columns,
            ghosting: ghostEffect, hoverclass: null, handle: draggableClass,
            dropOnEmpty: true, constraint: false, revert: false,
            starteffect: function(element) {if(minOnMove==true){Bloxpress.blockToggle(element, 'hide')} },
            endeffect: function(element) {if(minOnMove==true){if(!Bloxpress.in_array(element.id.split('_')[1], Bloxpress.managedBlocks)) {Bloxpress.blockToggle(element, 'show');}}},
            onUpdate:function() {Bloxpress.updateCookie()}
        });
    },
    createSortables: function() {
        if (this.columns.length > 0) {
            for (var i = 0; i < this.columns.length; i++) {
                this.setupColumn(this.columns[i]);
            }
            this.makeAllUnique();
        }
    },
    updateCookie: function() {
        this.cookie.cookieValue = this.serialize();
        this.cookie.update();
    },
    blockToggle: function(blockElement, force) {
        Element.cleanWhitespace(blockElement);
        if (force == null) {
            Element.toggle(blockElement.lastChild);
        } else {
            switch (force) {
                case 'hide': Element.hide(blockElement.lastChild); break;
                case 'show': Element.show(blockElement.lastChild); break;
            }
        }
    },
    checkDropped: function(desiredBlockId, targetColumn) {
        var colNum;
        for (var i = 0; i < this.blocksMenuItems.length; ++i)
        {
            if (desiredBlockId == this.blocksMenuItemIds[i])
            {
                for (var c = 0; c < this.columns.length; c++) {
                    if (targetColumn.id == this.columns[c]) {
                        colNum = c;
                        break;
                    }
                }
                var blockIdentfier = 'draggable' + colNum + '_' + this.blocksMenuItems[i]['file'].split(".")[0];
                var blockMessage = this.blocksMenuItems[i]['message'];
                var blockCaption = this.blocksMenuItems[i]['caption'];
                var blockContent = tplpath + 'blocks/' + this.blocksMenuItems[i]['file'];
                this.builderCreate(targetColumn, blockContent, blockIdentfier, blockCaption, blockMessage, 'menu');
            }
        }
    },
    blockStructure: function(blockid, caption, message)
    {
        return Builder.node('li', {id:blockid}, [
               Builder.node('div', {className:'caption'}, [
               Builder.node('h3', {className:draggableClass}, caption),
               Builder.node('a', {href:'javascript:;', className:'remove noscript', title:'Remove this block'}, [
               Builder.node('img', {src:closeImagePath, alt:'(x)'})]),
               Builder.node('a', {href:'javascript:;', className:'minmax noscript', title:'Minimize this block'}, [
               Builder.node('img', {src:minImagePath, alt:'(-)'})])]),
               Builder.node('div', {className:'content', id:blockid + '_content'}, [
               Builder.node('p', [Builder.node('img', {src:spinnerImagePath,style:'vertical-align:middle',alt:'wait'}), ' Loading ' + message + ' ... '])])
        ]);
    },
    blockManager: function(blockId, func) {
        /*blockId_base = blockId.match( /^(.*)_(.*)$/ );
        blockId = blockId_base[1];*/
        blockType = blockId.split('_')[1];
        switch(func){
            case 'add':
                 this.managedBlocks.push(blockType);
            break;
            case 'remove':
                for (var i = 0; i < this.managedBlocks.length; i++) {
                    if (this.managedBlocks[i] == blockType) this.managedBlocks.splice(i, 1);
                }
            break;
        }
        this.managedBlocksCookie.cookieValue = this.managedBlocks;
        this.managedBlocksCookie.update();
    },
    blockManagerSetup: function() {
        if(this.managedBlocksCookie.read() == null) this.managedBlocks = new Array();
        else this.managedBlocks = this.managedBlocksCookie.read().split(',');
        this.managedBlocksCookie.cookieValue = this.managedBlocks;
        this.managedBlocksCookie.cookieVerbose = false;
    },
    serialize: function() {
        var newLayout = '';
        for (var c = 0; c < this.columns.length; c++) {
            newLayout += Sortable.sequence(this.columns[c]);
            if (c != (this.columns.length - 1)) {
                newLayout += '##';
            }
        }
        return newLayout;
    },
    hideAllmanaged: function() {
        $$('.hideContent').each(function(e){
            Element.cleanWhitespace(e);
            Element.hide(e.lastChild);
            e.firstChild.getElementsByTagName('a')[1].title = 'Maximize this Block';
            e.firstChild.getElementsByTagName('img')[1].src = maxImagePath;
        });
    },
    makeAllUnique: function() {
        var allSortables = null;
        for (var i = 0; i < this.columns.length; i++) {
            allSortables = $(this.columns[i]).childNodes;
            if (allSortables.length > 0) {
                for (var x = 0; x < allSortables.length; x++) {
                    this.builderRandomId(allSortables[x]);
                }
            }
        }
    },
    errorMsg: function(element, text) {
        element.appendChild(Builder.node('div', {className:'error'}, [text + ' ', Builder.node('a', {href:'javascript:;',onclick:'Effect.DropOut(this.parentNode)'}, 'OK!')]));
    },
    xmlValue: function(xmlItem, tag) { // thanks quirksmode :)
        return xmlItem.getElementsByTagName(tag)[0].firstChild.nodeValue;
    },
    isUrl: function(urlstr) {
        var regexp = /(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/
        return regexp.test(urlstr);
    },
    clearColumn: function(col) {
        col.innerHTML = null;
    },
    getRandom: function(prefix) {
        return prefix + '_' + Math.round(Math.random() * 10000);
    },
	getCursors: function() {
		if(this.bType==-1) this.browserType();
		this.dragCursor();
	},
	browserType: function() {
		var browsers = new Array('opera', 'safari', 'msie', 'firefox', 'mozilla');
		var clientUA = navigator.userAgent.toLowerCase();
		for(var t=0; t < browsers.length; t++){
			if (clientUA.indexOf(browsers[t])!=-1){this.bType = t; break; }
		}
	},
	setupCursors: function() {
		$$(draggableClass).each(function(dragEl){
			dragEl.style.cursor = Bloxpress.grabCursor;
		});
	},
	dragCursor: function() { // try rich
		if(this.bType == 3 || this.bType == 4){
			this.grabCursor = '-moz-grab';
			this.grabbingCursor = '-moz-grabbing';
		} else { // use poor
			this.grabCursor = cursorGrab+', move';
			this.grabbingCursor = cursorGrabbing+', move';
		}
	},
	in_array: function(the_needle, the_haystack){
        var the_hay = the_haystack.toString();
        if(the_hay == ''){return false;}
        var the_pattern = new RegExp(the_needle, 'g');
        var matched = the_pattern.test(the_haystack);
        return matched;
    }
};